@@ -28,6 +28,7 @@ GIT_URL = './scm/userRemoteConfigs/hudson.plugins.git.UserRemoteConfig/url'
 HG_URL = './scm/source'
 GIT_BRANCH = './scm/branches/hudson.plugins.git.BranchSpec/name'
 HG_BRANCH = './scm/branch'
+DEFAULT_HG_BRANCH_NAME = 'default'
 
 log = logging.getLogger(__name__)
 
@@ -53,13 +54,13 @@ class Job(JenkinsBase, MutableJenkinsThing):
         self._scmurlmap = {
             'svn': lambda element_tree: list(element_tree.findall(SVN_URL)),
             'git': lambda element_tree: list(element_tree.findall(GIT_URL)),
-            'hg': lambda element_tree: list(element_tree.find(HG_URL)),
+            'hg': lambda element_tree: list(element_tree.findall(HG_URL)),
             None: lambda element_tree: []
         }
         self._scmbranchmap = {
             'svn': lambda element_tree: [],
             'git': lambda element_tree: list(element_tree.findall(GIT_BRANCH)),
-            'hg': lambda element_tree: list(element_tree.find(HG_BRANCH)),
+            'hg': self._get_hg_branch,
             None: lambda element_tree: []
         }
         JenkinsBase.__init__(self, url)
@@ -73,6 +74,17 @@ class Job(JenkinsBase, MutableJenkinsThing):
     def get_jenkins_obj(self):
         return self.jenkins
 
+    # When the name of the hg branch used in the job is default hg branch (i.e.
+    # default), Mercurial plugin doesn't store default branch name in config XML
+    # file of the job. Create XML node corresponding to default branch
+    def _get_hg_branch(self, element_tree):
+        branches = element_tree.findall(HG_BRANCH)
+        if not branches:
+            hg_default_branch = ET.Element('branch')
+            hg_default_branch.text = DEFAULT_HG_BRANCH_NAME
+            branches.append(hg_default_branch)
+        return branches
+
     def _poll(self):
         data = JenkinsBase._poll(self)
         # jenkins loads only the first 100 builds, load more if needed
@@ -87,11 +99,14 @@ class Job(JenkinsBase, MutableJenkinsThing):
         Jenkins API loads the first 100 builds and thus may not contain all builds
         information. This method checks if all builds are loaded in the data object
         and updates it with the missing builds if needed.'''
-        if not data.get("builds"):
+        if not (data.get("builds") and data.get("firstBuild")):
             return data
         # do not call _buildid_for_type here: it would poll and do an infinite loop
         oldest_loaded_build_number = data["builds"][-1]["number"]
-        first_build_number = data["firstBuild"]["number"]
+        if not data['firstBuild']:
+            first_build_number = oldest_loaded_build_number
+        else:
+            first_build_number = data["firstBuild"]["number"]
         all_builds_loaded = (oldest_loaded_build_number == first_build_number)
         if all_builds_loaded:
             return data
@@ -207,6 +222,7 @@ class Job(JenkinsBase, MutableJenkinsThing):
         """Gets a buildid for a given type of build"""
         self.poll()
         KNOWNBUILDTYPES = [
+            "lastStableBuild",
             "lastSuccessfulBuild",
             "lastBuild",
             "lastCompletedBuild",
@@ -224,6 +240,12 @@ class Job(JenkinsBase, MutableJenkinsThing):
         """
         return self._buildid_for_type("firstBuild")
 
+    def get_last_stable_buildnumber(self):
+        """
+        Get the numerical ID of the last stable build.
+        """
+        return self._buildid_for_type("lastStableBuild")
+
     def get_last_good_buildnumber(self):
         """
         Get the numerical ID of the last good build.
@@ -284,6 +306,13 @@ class Job(JenkinsBase, MutableJenkinsThing):
         """
         return self._data.get('nextBuildNumber', 0)
 
+    def get_last_stable_build(self):
+        """
+        Get the last stable build
+        """
+        bn = self.get_last_stable_buildnumber()
+        return self.get_build(bn)
+
     def get_last_good_build(self):
         """
         Get the last good build
